==> exo.platform.packaging.source-3.0.10.zip: exo-gwtframework-parent-1.0.8/exo-gwtframework-ui/src/main/java/org/exoplatform/gwtframework/ui/client/smartgwt/component/TextField.java <==
/**
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */

package org.exoplatform.gwtframework.ui.client.smartgwt.component;

import org.exoplatform.gwtframework.ui.client.api.TextFieldItem;
import org.exoplatform.gwtframework.ui.client.smartgwt.component.event.KeyPressHandlerImpl;

import com.google.gwt.event.dom.client.KeyPressHandler;
import com.google.gwt.event.logical.shared.ValueChangeHandler;
import com.google.gwt.event.shared.HandlerRegistration;
import com.smartgwt.client.widgets.form.fields.TextItem;

/**
 * Created by The eXo Platform SAS .
 * 
 * @author <a href="mailto:gavrikvetal@gmail.com">Vitaliy Gulyy</a>
 * @version $
 */

public class TextField extends TextItem implements TextFieldItem
{

   public TextField()
   {
   }

   public TextField(String name)
   {
      super(name);
   }

   public TextField(String name, String title)
   {
      super(name, title);
   }
   
   public String getValue()
   {
      return (super.getValue() == null) ? "" : "" + super.getValue();
   }

   public void setValue(String value)
   {
      super.setValue(value);
   }

   public void setValue(String value, boolean fireEvents)
   {
      setValue(value);
   }

   public HandlerRegistration addValueChangeHandler(ValueChangeHandler<String> valueChangeHandler)
   {
      return null;
   }

   public HandlerRegistration addKeyPressHandler(KeyPressHandler keyPressedHandler)
   {
      return super.addKeyPressHandler(new KeyPressHandlerImpl(keyPressedHandler));
   }   
}

==> exo.platform.packaging.source-3.5.8.zip: exo-gwtframework-parent-1.1.2/exo-gwtframework-ui/src/main/java/org/exoplatform/gwtframework/ui/client/smartgwt/component/TextField.java <==
/**
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */

package org.exoplatform.gwtframework.ui.client.smartgwt.component;

import org.exoplatform.gwtframework.ui.client.api.TextFieldItem;
import org.exoplatform.gwtframework.ui.client.smartgwt.component.event.ChangedHandlerImpl;
import org.exoplatform.gwtframework.ui.client.smartgwt.component.event.KeyPressHandlerImpl;

import com.google.gwt.event.dom.client.KeyPressHandler;
import com.google.gwt.event.logical.shared.ValueChangeHandler;
import com.google.gwt.event.shared.HandlerRegistration;
import com.smartgwt.client.widgets.form.fields.TextItem;

/**
 * Created by The eXo Platform SAS .
 * 
 * @author <a href="mailto:gavrikvetal@gmail.com">Vitaliy Gulyy</a>
 * @version $
 */

public class TextField extends TextItem implements TextFieldItem
{

   public TextField()
   {
   }

   public TextField(String name)
   {
      super(name);
   }

   public TextField(String name, String title)
   {
      super(name, title);
   }
   
   public String getValue()
   {
      return (super.getValue() == null) ? "" : "" + super.getValue();
   }

   public void setValue(String value)
   {
      super.setValue(value);
   }

   public void setValue(String value, boolean fireEvents)
   {
      setValue(value);
   }

   public HandlerRegistration addValueChangeHandler(ValueChangeHandler<String> valueChangeHandler)
   {
      return super.addChangedHandler(new ChangedHandlerImpl(valueChangeHandler));
   }

   public HandlerRegistration addKeyPressHandler(KeyPressHandler keyPressedHandler)
   {
      return super.addKeyPressHandler(new KeyPressHandlerImpl(keyPressedHandler));
   }   
}
